@@ -589,7 +589,9 @@ has _lists => (
     writer => '_set_lists',
     handles => { 
         list => 'get_list', 
+        get_list => 'get_list',
         lists => 'get_lists', 
+        get_lists => 'get_lists',
         lists_with_object => 'get_lists_with_object',
         list_names => 'get_list_names',
         new_list => 'new_list',
